# Changelog

## 0.1.2 - 2022-05-18

+ Fix serialization of strings that include half surrogate pair `[char]` values

## 0.1.1 - 2022-04-06

+ Do not use references for lists and dict types when serializing

## 0.1.0 - 2022-03-28

Initial release
